==> antiright-3.0.tar.bz2: antiright-3.0/gtkshell/option_options.c <==
/*
  AntiRight
  (c) 2002-2007 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

void
gsh_handle_option_arguments(struct GSH * gsh, int argc, char **argv,
			    int *counter)
{
	switch (argv[(*counter)][2])
	{
	case 'E':		/* Make a text entry simpley print the
				 * text.  */
		gsh->bflags |= GSH_PROMPT_ECHOES;
		break;
	case 'e':
		gsh->bflags |= GSH_CBEXIT;
		break;
	case 'f':
		gsh->bflags |= GSH_FRAMED_LABELS;
		break;
	case 'g':
		gsh_count(argc, counter);

		ARIFP(gsh->geometry)
			free(gsh->geometry);

		ar_asprintf(&gsh->geometry, "%s", argv[(*counter)]);

		break;
	case 'h':
		gsh->bflags |= GSH_HORIZONTAL_LABELS;
		break;
	case 'n':

		gtk_window_set_decorated(GTK_WINDOW(gsh->window),
					 FALSE);

		gtk_window_set_skip_taskbar_hint
			(GTK_WINDOW(gsh->window), TRUE);

		break;
	case 'r':
		gsh_count(argc, counter);
		gsh->rows.rows =
			(unsigned int) atoi(argv[(*counter)]);
		break;
	case 'u':
		gsh_count(argc, counter);
		gsh->update.period = atoi(argv[*counter]);
		break;
	}
}

==> antiright-3.1.1.tar.bz2: antiright-3.1.1/gtkshell/option_options.c <==
/*
  AntiRight
  (c) 2002-2007 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, 
  Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

void
gsh_handle_option_arguments(struct GSH * gsh, int argc, char **argv,
			    int *counter)
{
	switch (argv[(*counter)][2])
	{
	case 'E':		/* Make a text entry simply print the
				 * text.  */
		GSH_SET(GSH_PROMPT_ECHOES);
		break;
	case 'e':
		GSH_SET(GSH_CBEXIT);
		break;
	case 'F':
		GSH_SET(GSH_NO_BASE_FRAME);
		break;
	case 'f':
		GSH_SET(GSH_FRAMED_LABELS);
		break;
	case 'g':
		gsh_count(argc, counter);

		ARIFP(gsh->geometry)
			free(gsh->geometry);

		ar_asprintf(&gsh->geometry, "%s", argv[(*counter)]);

		break;
	case 'h':
		GSH_SET(GSH_HORIZONTAL_LABELS);
		break;
	case 'n':

		gtk_window_set_decorated(GTK_WINDOW(gsh->window),
					 FALSE);

		gtk_window_set_skip_taskbar_hint
			(GTK_WINDOW(gsh->window), TRUE);

		break;
	case 'r':
		gsh_count(argc, counter);
		gsh->rows.rows =
			(unsigned int) atoi(argv[(*counter)]);
		break;

	case 'S':
		gsh_count(argc, counter);
		gsh->terminal.font=strdup(argv[*counter]);
		break;

	case 'T':
		gsh_count(argc, counter);
		gsh->terminal.font=argv[*counter];
		break;

	case 'u':
		gsh_count(argc, counter);
		gsh->update.period = atoi(argv[*counter]);
		break;
	}
}
